@@ -1,4 +1,4 @@
-  /********************************************************************\
+/********************************************************************\
   * BitlBee -- An IRC to other IM-networks gateway                     *
   *                                                                    *
   * Copyright 2002-2013 Wilmer van der Gaast and others                *
@@ -19,8 +19,8 @@
 
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _BITLBEE_H
@@ -34,14 +34,11 @@ extern "C" {
 #define _GNU_SOURCE /* Stupid GNU :-P */
 #endif
 
-/* Depend on Windows 2000 for now since we need getaddrinfo() */
-#define _WIN32_WINNT 0x0501
-
 #define PACKAGE "BitlBee"
-#define BITLBEE_VERSION "3.2.2"
+#define BITLBEE_VERSION "3.4"
 #define VERSION BITLBEE_VERSION
-#define BITLBEE_VER(a,b,c) (((a) << 16) + ((b) << 8) + (c))
-#define BITLBEE_VERSION_CODE BITLBEE_VER(3, 2, 2)
+#define BITLBEE_VER(a, b, c) (((a) << 16) + ((b) << 8) + (c))
+#define BITLBEE_VERSION_CODE BITLBEE_VER(3, 4, 0)
 
 #define MAX_STRING 511
 
@@ -59,52 +56,48 @@ extern "C" {
 #include <stdio.h>
 #include <ctype.h>
 #include <errno.h>
-
-#ifndef _WIN32
 #include <syslog.h>
-#endif
-
 #include <glib.h>
 #include <gmodule.h>
 
 /* The following functions should not be used if we want to maintain Windows compatibility... */
 #undef free
-#define free		__PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
+#define free            __PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
 #undef malloc
-#define malloc		__PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
+#define malloc          __PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
 #undef calloc
-#define calloc		__PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
+#define calloc          __PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
 #undef realloc
-#define realloc		__PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
+#define realloc         __PLEASE_USE_THE_GLIB_MEMORY_ALLOCATION_SYSTEM__
 #undef strdup
-#define strdup		__PLEASE_USE_THE_GLIB_STRDUP_FUNCTIONS_SYSTEM__
+#define strdup          __PLEASE_USE_THE_GLIB_STRDUP_FUNCTIONS_SYSTEM__
 #undef strndup
-#define strndup		__PLEASE_USE_THE_GLIB_STRDUP_FUNCTIONS_SYSTEM__
+#define strndup         __PLEASE_USE_THE_GLIB_STRDUP_FUNCTIONS_SYSTEM__
 #undef snprintf
-#define snprintf	__PLEASE_USE_G_SNPRINTF__
+#define snprintf        __PLEASE_USE_G_SNPRINTF__
 #undef strcasecmp
-#define strcasecmp	__PLEASE_USE_G_STRCASECMP__
+#define strcasecmp      __PLEASE_USE_G_STRCASECMP__
 #undef strncasecmp
-#define strncasecmp	__PLEASE_USE_G_STRNCASECMP__
+#define strncasecmp     __PLEASE_USE_G_STRNCASECMP__
 
 /* And the following functions shouldn't be used anymore to keep compatibility
    with other event handling libs than GLib. */
 #undef g_timeout_add
-#define g_timeout_add		__PLEASE_USE_B_TIMEOUT_ADD__
+#define g_timeout_add           __PLEASE_USE_B_TIMEOUT_ADD__
 #undef g_timeout_add_full
-#define g_timeout_add_full	__PLEASE_USE_B_TIMEOUT_ADD__
+#define g_timeout_add_full      __PLEASE_USE_B_TIMEOUT_ADD__
 #undef g_io_add_watch
-#define g_io_add_watch		__PLEASE_USE_B_INPUT_ADD__
+#define g_io_add_watch          __PLEASE_USE_B_INPUT_ADD__
 #undef g_io_add_watch_full
-#define g_io_add_watch_full	__PLEASE_USE_B_INPUT_ADD__
+#define g_io_add_watch_full     __PLEASE_USE_B_INPUT_ADD__
 #undef g_source_remove
-#define g_source_remove		__PLEASE_USE_B_EVENT_REMOVE__
+#define g_source_remove         __PLEASE_USE_B_EVENT_REMOVE__
 #undef g_source_remove_by_user_data
-#define g_source_remove_by_user_data	__PLEASE_USE_B_SOURCE_REMOVE_BY_USER_DATA__
+#define g_source_remove_by_user_data    __PLEASE_USE_B_SOURCE_REMOVE_BY_USER_DATA__
 #undef g_main_run
-#define g_main_run		__PLEASE_USE_B_MAIN_RUN__
+#define g_main_run              __PLEASE_USE_B_MAIN_RUN__
 #undef g_main_quit
-#define g_main_quit		__PLEASE_USE_B_MAIN_QUIT__
+#define g_main_quit             __PLEASE_USE_B_MAIN_QUIT__
 
 /* And now, because GLib folks think everyone loves typing ridiculously long
    function names ... no I don't or I'd write BitlBee in Java, ffs. */
@@ -117,7 +110,7 @@ extern "C" {
 #define G_GNUC_MALLOC
 #endif
 
-#define _( x ) x
+#define _(x) x
 
 #define ROOT_NICK "root"
 #define ROOT_CHAN "&bitlbee"
@@ -166,20 +159,20 @@ typedef struct global {
 	int restart;
 } global_t;
 
-int bitlbee_daemon_init( void );
-int bitlbee_inetd_init( void );
+int bitlbee_daemon_init(void);
+int bitlbee_inetd_init(void);
 
-gboolean bitlbee_io_current_client_read( gpointer data, gint source, b_input_condition cond );
-gboolean bitlbee_io_current_client_write( gpointer data, gint source, b_input_condition cond );
+gboolean bitlbee_io_current_client_read(gpointer data, gint source, b_input_condition cond);
+gboolean bitlbee_io_current_client_write(gpointer data, gint source, b_input_condition cond);
 
-void root_command_string( irc_t *irc, char *command );
-void root_command( irc_t *irc, char *command[] );
-gboolean root_command_add( const char *command, int params, void (*func)(irc_t *, char **args), int flags );
-gboolean cmd_identify_finish( gpointer data, gint fd, b_input_condition cond );
-gboolean bitlbee_shutdown( gpointer data, gint fd, b_input_condition cond );
+void root_command_string(irc_t *irc, char *command);
+void root_command(irc_t *irc, char *command[]);
+gboolean root_command_add(const char *command, int params, void (*func)(irc_t *, char **args), int flags);
+gboolean cmd_identify_finish(gpointer data, gint fd, b_input_condition cond);
+gboolean bitlbee_shutdown(gpointer data, gint fd, b_input_condition cond);
 
-char *set_eval_root_nick( set_t *set, char *new_nick );
-char *set_eval_control_channel( set_t *set, char *new_name );
+char *set_eval_root_nick(set_t *set, char *new_nick);
+char *set_eval_control_channel(set_t *set, char *new_name);
 
 extern global_t global;
 
