@@ -1,4 +1,4 @@
-  /********************************************************************\
+/********************************************************************\
   * BitlBee -- An IRC to other IM-networks gateway                     *
   *                                                                    *
   * Copyright 2002-2006 Wilmer van der Gaast and others                *
@@ -21,8 +21,8 @@
 
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #define BITLBEE_CORE
@@ -30,17 +30,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
-#ifndef _WIN32
 #include <sys/socket.h>
 #include <netdb.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <unistd.h>
-#else
-#include "sock.h"
-#define ETIMEDOUT WSAETIMEDOUT
-#define EINPROGRESS WSAEINPROGRESS
-#endif
 #include <fcntl.h>
 #include <errno.h>
 #include "proxy.h"
@@ -55,18 +49,19 @@ static GMainLoop *loop = NULL;
 
 void b_main_init()
 {
-	if( loop == NULL )
-		loop = g_main_new( FALSE );
+	if (loop == NULL) {
+		loop = g_main_new(FALSE);
+	}
 }
 
 void b_main_run()
 {
-	g_main_run( loop );
+	g_main_run(loop);
 }
 
 void b_main_quit()
 {
-	g_main_quit( loop );
+	g_main_quit(loop);
 }
 
 static gboolean gaim_io_invoke(GIOChannel *source, GIOCondition condition, gpointer data)
@@ -75,29 +70,37 @@ static gboolean gaim_io_invoke(GIOChannel *source, GIOCondition condition, gpoin
 	b_input_condition gaim_cond = 0;
 	gboolean st;
 
-	if (condition & GAIM_READ_COND)
+	if (condition & G_IO_NVAL) {
+		return FALSE;
+	}
+
+	if (condition & GAIM_READ_COND) {
 		gaim_cond |= B_EV_IO_READ;
-	if (condition & GAIM_WRITE_COND)
+	}
+	if (condition & GAIM_WRITE_COND) {
 		gaim_cond |= B_EV_IO_WRITE;
-	
-	event_debug( "gaim_io_invoke( %d, %d, 0x%x )\n", g_io_channel_unix_get_fd(source), condition, data );
+	}
+
+	event_debug("gaim_io_invoke( %d, %d, 0x%x )\n", g_io_channel_unix_get_fd(source), condition, data);
 
 	st = closure->function(closure->data, g_io_channel_unix_get_fd(source), gaim_cond);
-	
-	if( !st )
-		event_debug( "Returned FALSE, cancelling.\n" );
-	
-	if (closure->flags & B_EV_FLAG_FORCE_ONCE)
+
+	if (!st) {
+		event_debug("Returned FALSE, cancelling.\n");
+	}
+
+	if (closure->flags & B_EV_FLAG_FORCE_ONCE) {
 		return FALSE;
-	else if (closure->flags & B_EV_FLAG_FORCE_REPEAT)
+	} else if (closure->flags & B_EV_FLAG_FORCE_REPEAT) {
 		return TRUE;
-	else
+	} else {
 		return st;
+	}
 }
 
 static void gaim_io_destroy(gpointer data)
 {
-	event_debug( "gaim_io_destroy( 0x%x )\n", data );
+	event_debug("gaim_io_destroy( 0x%x )\n", data);
 	g_free(data);
 }
 
@@ -107,22 +110,24 @@ gint b_input_add(gint source, b_input_condition condition, b_event_handler funct
 	GIOChannel *channel;
 	GIOCondition cond = 0;
 	int st;
-	
+
 	closure->function = function;
 	closure->data = data;
 	closure->flags = condition;
-	
-	if (condition & B_EV_IO_READ)
+
+	if (condition & B_EV_IO_READ) {
 		cond |= GAIM_READ_COND;
-	if (condition & B_EV_IO_WRITE)
+	}
+	if (condition & B_EV_IO_WRITE) {
 		cond |= GAIM_WRITE_COND;
-	
+	}
+
 	channel = g_io_channel_unix_new(source);
 	st = g_io_add_watch_full(channel, G_PRIORITY_DEFAULT, cond,
 	                         gaim_io_invoke, closure, gaim_io_destroy);
-	
-	event_debug( "b_input_add( %d, %d, 0x%x, 0x%x ) = %d (%p)\n", source, condition, function, data, st, closure );
-	
+
+	event_debug("b_input_add( %d, %d, 0x%x, 0x%x ) = %d (%p)\n", source, condition, function, data, st, closure);
+
 	g_io_channel_unref(channel);
 	return st;
 }
@@ -133,21 +138,22 @@ gint b_timeout_add(gint timeout, b_event_handler func, gpointer data)
 	   really the same, but they're "compatible". ;-) It will do
 	   for now, BitlBee only looks at the "data" argument. */
 	gint st = g_timeout_add(timeout, (GSourceFunc) func, data);
-	
-	event_debug( "b_timeout_add( %d, %d, %d ) = %d\n", timeout, func, data, st );
-	
+
+	event_debug("b_timeout_add( %d, %d, %d ) = %d\n", timeout, func, data, st);
+
 	return st;
 }
 
 void b_event_remove(gint tag)
 {
-	event_debug( "b_event_remove( %d )\n", tag );
-	
-	if (tag > 0)
+	event_debug("b_event_remove( %d )\n", tag);
+
+	if (tag > 0) {
 		g_source_remove(tag);
+	}
 }
 
-void closesocket( int fd )
+void closesocket(int fd)
 {
-	close( fd );
+	close(fd);
 }
