@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -25,17 +25,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
-#ifndef _WIN32
 #include <sys/socket.h>
 #include <netdb.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <unistd.h>
-#else
-#include "sock.h"
-#define ETIMEDOUT WSAETIMEDOUT
-#define EINPROGRESS WSAEINPROGRESS
-#endif
 #include <fcntl.h>
 #include <errno.h>
 #include "nogaim.h"
@@ -71,11 +65,11 @@ static int proxy_connect_none(const char *host, unsigned short port_, struct PHB
 static gboolean gaim_io_connected(gpointer data, gint source, b_input_condition cond)
 {
 	struct PHB *phb = data;
-	unsigned int len;
+	socklen_t len;
 	int error = ETIMEDOUT;
+
 	len = sizeof(error);
-	
-#ifndef _WIN32
+
 	if (getsockopt(source, SOL_SOCKET, SO_ERROR, &error, &len) < 0 || error) {
 		if ((phb->gai_cur = phb->gai_cur->ai_next)) {
 			int new_fd;
@@ -92,25 +86,26 @@ static gboolean gaim_io_connected(gpointer data, gint source, b_input_condition
 		freeaddrinfo(phb->gai);
 		closesocket(source);
 		b_event_remove(phb->inpa);
-		if( phb->proxy_func )
+		phb->inpa = 0;
+		if (phb->proxy_func) {
 			phb->proxy_func(phb->proxy_data, -1, B_EV_IO_READ);
-		else {
+		} else {
 			phb->func(phb->data, -1, B_EV_IO_READ);
 			g_free(phb);
 		}
 		return FALSE;
 	}
-#endif
 	freeaddrinfo(phb->gai);
 	sock_make_blocking(source);
 	b_event_remove(phb->inpa);
-	if( phb->proxy_func )
+	phb->inpa = 0;
+	if (phb->proxy_func) {
 		phb->proxy_func(phb->proxy_data, source, B_EV_IO_READ);
-	else {
+	} else {
 		phb->func(phb->data, source, B_EV_IO_READ);
 		g_free(phb);
 	}
-	
+
 	return FALSE;
 }
 
@@ -118,62 +113,62 @@ static int proxy_connect_none(const char *host, unsigned short port_, struct PHB
 {
 	struct sockaddr_in me;
 	int fd = -1;
-	
-	if (phb->gai_cur == NULL)
-	{
+
+	if (phb->gai_cur == NULL) {
 		int ret;
 		char port[6];
 		struct addrinfo hints;
-	
+
 		g_snprintf(port, sizeof(port), "%d", port_);
-	
+
 		memset(&hints, 0, sizeof(struct addrinfo));
 		hints.ai_family = AF_UNSPEC;
 		hints.ai_socktype = SOCK_STREAM;
 		hints.ai_flags = AI_ADDRCONFIG | AI_NUMERICSERV;
-	
-		if (!(ret = getaddrinfo(host, port, &hints, &phb->gai)))
+
+		if (!(ret = getaddrinfo(host, port, &hints, &phb->gai))) {
 			phb->gai_cur = phb->gai;
-		else
+		} else {
 			event_debug("gai(): %s\n", gai_strerror(ret));
+		}
 	}
-	
-	for (; phb->gai_cur; phb->gai_cur = phb->gai_cur->ai_next)
-	{
+
+	for (; phb->gai_cur; phb->gai_cur = phb->gai_cur->ai_next) {
 		if ((fd = socket(phb->gai_cur->ai_family, phb->gai_cur->ai_socktype, phb->gai_cur->ai_protocol)) < 0) {
-			event_debug( "socket failed: %d\n", errno);
+			event_debug("socket failed: %d\n", errno);
 			continue;
 		}
 
 		sock_make_nonblocking(fd);
 
-		if (global.conf->iface_out)
-		{
+		if (global.conf->iface_out) {
 			me.sin_family = AF_INET;
 			me.sin_port = 0;
-			me.sin_addr.s_addr = inet_addr( global.conf->iface_out );
-				
-			if (bind(fd, (struct sockaddr *) &me, sizeof(me)) != 0)
+			me.sin_addr.s_addr = inet_addr(global.conf->iface_out);
+
+			if (bind(fd, (struct sockaddr *) &me, sizeof(me)) != 0) {
 				event_debug("bind( %d, \"%s\" ) failure\n", fd, global.conf->iface_out);
+			}
 		}
 
-		event_debug("proxy_connect_none( \"%s\", %d ) = %d\n", host, port, fd);
-	
+		event_debug("proxy_connect_none( \"%s\", %d ) = %d\n", host, port_, fd);
+
 		if (connect(fd, phb->gai_cur->ai_addr, phb->gai_cur->ai_addrlen) < 0 && !sockerr_again()) {
-			event_debug( "connect failed: %s\n", strerror(errno));
+			event_debug("connect failed: %s\n", strerror(errno));
 			closesocket(fd);
 			fd = -1;
 			continue;
 		} else {
 			phb->inpa = b_input_add(fd, B_EV_IO_WRITE, gaim_io_connected, phb);
 			phb->fd = fd;
-			
+
 			break;
 		}
 	}
-	
-	if(fd < 0 && host)
+
+	if (fd < 0 && host) {
 		g_free(phb);
+	}
 
 	return fd;
 }
@@ -181,8 +176,8 @@ static int proxy_connect_none(const char *host, unsigned short port_, struct PHB
 
 /* Connecting to HTTP proxies */
 
-#define HTTP_GOODSTRING "HTTP/1.0 200 Connection established"
-#define HTTP_GOODSTRING2 "HTTP/1.1 200 Connection established"
+#define HTTP_GOODSTRING "HTTP/1.0 200"
+#define HTTP_GOODSTRING2 "HTTP/1.1 200"
 
 static gboolean http_canread(gpointer data, gint source, b_input_condition cond)
 {
@@ -193,11 +188,12 @@ static gboolean http_canread(gpointer data, gint source, b_input_condition cond)
 
 	b_event_remove(phb->inpa);
 
-	while ((pos < sizeof(inputline)-1) && (nlc != 2) && (read(source, &inputline[pos++], 1) == 1)) {
-		if (inputline[pos - 1] == '\n')
+	while ((pos < sizeof(inputline) - 1) && (nlc != 2) && (read(source, &inputline[pos++], 1) == 1)) {
+		if (inputline[pos - 1] == '\n') {
 			nlc++;
-		else if (inputline[pos - 1] != '\r')
+		} else if (inputline[pos - 1] != '\r') {
 			nlc = 0;
+		}
 	}
 	inputline[pos] = '\0';
 
@@ -213,7 +209,7 @@ static gboolean http_canread(gpointer data, gint source, b_input_condition cond)
 	phb->func(phb->data, -1, B_EV_IO_READ);
 	g_free(phb->host);
 	g_free(phb);
-	
+
 	return FALSE;
 }
 
@@ -221,10 +217,12 @@ static gboolean http_canwrite(gpointer data, gint source, b_input_condition cond
 {
 	char cmd[384];
 	struct PHB *phb = data;
-	unsigned int len;
+	socklen_t len;
 	int error = ETIMEDOUT;
-	if (phb->inpa > 0)
+
+	if (phb->inpa > 0) {
 		b_event_remove(phb->inpa);
+	}
 	len = sizeof(error);
 	if (getsockopt(source, SOL_SOCKET, SO_ERROR, &error, &len) < 0) {
 		close(source);
@@ -236,7 +234,7 @@ static gboolean http_canwrite(gpointer data, gint source, b_input_condition cond
 	sock_make_blocking(source);
 
 	g_snprintf(cmd, sizeof(cmd), "CONNECT %s:%d HTTP/1.1\r\nHost: %s:%d\r\n", phb->host, phb->port,
-		   phb->host, phb->port);
+	           phb->host, phb->port);
 	if (send(source, cmd, strlen(cmd), 0) < 0) {
 		close(source);
 		phb->func(phb->data, -1, B_EV_IO_READ);
@@ -271,7 +269,7 @@ static gboolean http_canwrite(gpointer data, gint source, b_input_condition cond
 	}
 
 	phb->inpa = b_input_add(source, B_EV_IO_READ, http_canread, phb);
-	
+
 	return FALSE;
 }
 
@@ -281,8 +279,8 @@ static int proxy_connect_http(const char *host, unsigned short port, struct PHB
 	phb->port = port;
 	phb->proxy_func = http_canwrite;
 	phb->proxy_data = phb;
-	
-	return( proxy_connect_none( proxyhost, proxyport, phb ) );
+
+	return(proxy_connect_none(proxyhost, proxyport, phb));
 }
 
 
@@ -307,7 +305,7 @@ static gboolean s4_canread(gpointer data, gint source, b_input_condition cond)
 	phb->func(phb->data, -1, B_EV_IO_READ);
 	g_free(phb->host);
 	g_free(phb);
-	
+
 	return FALSE;
 }
 
@@ -316,10 +314,12 @@ static gboolean s4_canwrite(gpointer data, gint source, b_input_condition cond)
 	unsigned char packet[12];
 	struct hostent *hp;
 	struct PHB *phb = data;
-	unsigned int len;
+	socklen_t len;
 	int error = ETIMEDOUT;
-	if (phb->inpa > 0)
+
+	if (phb->inpa > 0) {
 		b_event_remove(phb->inpa);
+	}
 	len = sizeof(error);
 	if (getsockopt(source, SOL_SOCKET, SO_ERROR, &error, &len) < 0) {
 		close(source);
@@ -343,10 +343,10 @@ static gboolean s4_canwrite(gpointer data, gint source, b_input_condition cond)
 	packet[1] = 1;
 	packet[2] = phb->port >> 8;
 	packet[3] = phb->port & 0xff;
-	packet[4] = (unsigned char)(hp->h_addr_list[0])[0];
-	packet[5] = (unsigned char)(hp->h_addr_list[0])[1];
-	packet[6] = (unsigned char)(hp->h_addr_list[0])[2];
-	packet[7] = (unsigned char)(hp->h_addr_list[0])[3];
+	packet[4] = (unsigned char) (hp->h_addr_list[0])[0];
+	packet[5] = (unsigned char) (hp->h_addr_list[0])[1];
+	packet[6] = (unsigned char) (hp->h_addr_list[0])[2];
+	packet[7] = (unsigned char) (hp->h_addr_list[0])[3];
 	packet[8] = 0;
 	if (write(source, packet, 9) != 9) {
 		close(source);
@@ -357,7 +357,7 @@ static gboolean s4_canwrite(gpointer data, gint source, b_input_condition cond)
 	}
 
 	phb->inpa = b_input_add(source, B_EV_IO_READ, s4_canread, phb);
-	
+
 	return FALSE;
 }
 
@@ -367,8 +367,8 @@ static int proxy_connect_socks4(const char *host, unsigned short port, struct PH
 	phb->port = port;
 	phb->proxy_func = s4_canwrite;
 	phb->proxy_data = phb;
-	
-	return( proxy_connect_none( proxyhost, proxyport, phb ) );
+
+	return(proxy_connect_none(proxyhost, proxyport, phb));
 }
 
 
@@ -399,7 +399,7 @@ static gboolean s5_canread_again(gpointer data, gint source, b_input_condition c
 	phb->func(phb->data, source, B_EV_IO_READ);
 	g_free(phb->host);
 	g_free(phb);
-	
+
 	return FALSE;
 }
 
@@ -408,11 +408,11 @@ static void s5_sendconnect(gpointer data, gint source)
 	unsigned char buf[512];
 	struct PHB *phb = data;
 	int hlen = strlen(phb->host);
-	
+
 	buf[0] = 0x05;
-	buf[1] = 0x01;		/* CONNECT */
-	buf[2] = 0x00;		/* reserved */
-	buf[3] = 0x03;		/* address type -- host name */
+	buf[1] = 0x01;          /* CONNECT */
+	buf[2] = 0x00;          /* reserved */
+	buf[3] = 0x03;          /* address type -- host name */
 	buf[4] = hlen;
 	memcpy(buf + 5, phb->host, hlen);
 	buf[5 + strlen(phb->host)] = phb->port >> 8;
@@ -453,7 +453,7 @@ static gboolean s5_readauth(gpointer data, gint source, b_input_condition cond)
 	}
 
 	s5_sendconnect(phb, source);
-	
+
 	return FALSE;
 }
 
@@ -482,7 +482,7 @@ static gboolean s5_canread(gpointer data, gint source, b_input_condition cond)
 
 	if (buf[1] == 0x02) {
 		unsigned int i = strlen(proxyuser), j = strlen(proxypass);
-		buf[0] = 0x01;	/* version 1 */
+		buf[0] = 0x01;  /* version 1 */
 		buf[1] = i;
 		memcpy(buf + 2, proxyuser, i);
 		buf[2 + i] = j;
@@ -499,7 +499,7 @@ static gboolean s5_canread(gpointer data, gint source, b_input_condition cond)
 	} else {
 		s5_sendconnect(phb, source);
 	}
-	
+
 	return FALSE;
 }
 
@@ -508,10 +508,12 @@ static gboolean s5_canwrite(gpointer data, gint source, b_input_condition cond)
 	unsigned char buf[512];
 	int i;
 	struct PHB *phb = data;
-	unsigned int len;
+	socklen_t len;
 	int error = ETIMEDOUT;
-	if (phb->inpa > 0)
+
+	if (phb->inpa > 0) {
 		b_event_remove(phb->inpa);
+	}
 	len = sizeof(error);
 	if (getsockopt(source, SOL_SOCKET, SO_ERROR, &error, &len) < 0) {
 		close(source);
@@ -523,11 +525,11 @@ static gboolean s5_canwrite(gpointer data, gint source, b_input_condition cond)
 	sock_make_blocking(source);
 
 	i = 0;
-	buf[0] = 0x05;		/* SOCKS version 5 */
+	buf[0] = 0x05;          /* SOCKS version 5 */
 	if (proxyuser[0]) {
-		buf[1] = 0x02;	/* two methods */
-		buf[2] = 0x00;	/* no authentication */
-		buf[3] = 0x02;	/* username/password authentication */
+		buf[1] = 0x02;  /* two methods */
+		buf[2] = 0x00;  /* no authentication */
+		buf[3] = 0x02;  /* username/password authentication */
 		i = 4;
 	} else {
 		buf[1] = 0x01;
@@ -544,7 +546,7 @@ static gboolean s5_canwrite(gpointer data, gint source, b_input_condition cond)
 	}
 
 	phb->inpa = b_input_add(source, B_EV_IO_READ, s5_canread, phb);
-	
+
 	return FALSE;
 }
 
@@ -554,8 +556,8 @@ static int proxy_connect_socks5(const char *host, unsigned short port, struct PH
 	phb->port = port;
 	phb->proxy_func = s5_canwrite;
 	phb->proxy_data = phb;
-	
-	return( proxy_connect_none( proxyhost, proxyport, phb ) );
+
+	return(proxy_connect_none(proxyhost, proxyport, phb));
 }
 
 
@@ -564,24 +566,25 @@ static int proxy_connect_socks5(const char *host, unsigned short port, struct PH
 int proxy_connect(const char *host, int port, b_event_handler func, gpointer data)
 {
 	struct PHB *phb;
-	
+
 	if (!host || port <= 0 || !func || strlen(host) > 128) {
 		return -1;
 	}
-	
+
 	phb = g_new0(struct PHB, 1);
 	phb->func = func;
 	phb->data = data;
-	
-	if (proxytype == PROXY_NONE || !proxyhost[0] || proxyport <= 0)
+
+	if (proxytype == PROXY_NONE || !proxyhost[0] || proxyport <= 0) {
 		return proxy_connect_none(host, port, phb);
-	else if (proxytype == PROXY_HTTP)
+	} else if (proxytype == PROXY_HTTP) {
 		return proxy_connect_http(host, port, phb);
-	else if (proxytype == PROXY_SOCKS4)
+	} else if (proxytype == PROXY_SOCKS4) {
 		return proxy_connect_socks4(host, port, phb);
-	else if (proxytype == PROXY_SOCKS5)
+	} else if (proxytype == PROXY_SOCKS5) {
 		return proxy_connect_socks5(host, port, phb);
-	
+	}
+
 	g_free(phb);
 	return -1;
 }
