@@ -1,7 +1,7 @@
-  /********************************************************************\
+/********************************************************************\
   * BitlBee -- An IRC to other IM-networks gateway                     *
   *                                                                    *
-  * Copyright 2002-2004 Wilmer van der Gaast and others                *
+  * Copyright 2002-2010 Wilmer van der Gaast and others                *
   \********************************************************************/
 
 /* MSN module - Some tables with useful data                            */
@@ -19,8 +19,8 @@
 
   You should have received a copy of the GNU General Public License with
   the Debian GNU/Linux distribution in /usr/share/common-licenses/GPL;
-  if not, write to the Free Software Foundation, Inc., 59 Temple Place,
-  Suite 330, Boston, MA  02111-1307  USA
+  if not, write to the Free Software Foundation, Inc., 51 Franklin St.,
+  Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "nogaim.h"
@@ -39,25 +39,29 @@ const struct msn_away_state msn_away_state_list[] =
 	{ "",    "" }
 };
 
-const struct msn_away_state *msn_away_state_by_code( char *code )
+const struct msn_away_state *msn_away_state_by_code(char *code)
 {
 	int i;
-	
-	for( i = 0; *msn_away_state_list[i].code; i ++ )
-		if( g_strcasecmp( msn_away_state_list[i].code, code ) == 0 )
-			return( msn_away_state_list + i );
-	
+
+	for (i = 0; *msn_away_state_list[i].code; i++) {
+		if (g_strcasecmp(msn_away_state_list[i].code, code) == 0) {
+			return(msn_away_state_list + i);
+		}
+	}
+
 	return NULL;
 }
 
-const struct msn_away_state *msn_away_state_by_name( char *name )
+const struct msn_away_state *msn_away_state_by_name(char *name)
 {
 	int i;
-	
-	for( i = 0; *msn_away_state_list[i].code; i ++ )
-		if( g_strcasecmp( msn_away_state_list[i].name, name ) == 0 )
-			return( msn_away_state_list + i );
-	
+
+	for (i = 0; *msn_away_state_list[i].code; i++) {
+		if (g_strcasecmp(msn_away_state_list[i].name, name) == 0) {
+			return(msn_away_state_list + i);
+		}
+	}
+
 	return NULL;
 }
 
@@ -82,26 +86,28 @@ const struct msn_status_code msn_status_code_list[] =
 	{ 229, "Group name too long",                                   0 },
 	{ 230, "Cannot remove that group",                              0 },
 	{ 231, "Invalid group",                                         0 },
+	{ 240, "ADL/RML command with corrupted payload",                STATUS_FATAL },
+	{ 241, "ADL/RML command with invalid modification",             0 },
 	{ 280, "Switchboard failed",                                    STATUS_SB_FATAL },
 	{ 281, "Transfer to switchboard failed",                        0 },
-	
+
 	{ 300, "Required field missing",                                0 },
 	{ 302, "Not logged in",                                         0 },
-	
+
 	{ 500, "Internal server error/Account banned",                  STATUS_FATAL },
 	{ 501, "Database server error",                                 STATUS_FATAL },
 	{ 502, "Command disabled",                                      0 },
 	{ 510, "File operation failed",                                 STATUS_FATAL },
 	{ 520, "Memory allocation failed",                              STATUS_FATAL },
 	{ 540, "Challenge response invalid",                            STATUS_FATAL },
-	
+
 	{ 600, "Server is busy",                                        STATUS_FATAL },
 	{ 601, "Server is unavailable",                                 STATUS_FATAL },
 	{ 602, "Peer nameserver is down",                               STATUS_FATAL },
 	{ 603, "Database connection failed",                            STATUS_FATAL },
 	{ 604, "Server is going down",                                  STATUS_FATAL },
 	{ 605, "Server is unavailable",                                 STATUS_FATAL },
-	
+
 	{ 700, "Could not create connection",                           STATUS_FATAL },
 	{ 710, "Invalid CVR parameters",                                STATUS_FATAL },
 	{ 711, "Write is blocking",                                     STATUS_FATAL },
@@ -111,9 +117,9 @@ const struct msn_status_code msn_status_code_list[] =
 	{ 715, "Not expected/Invalid argument/action",                  0 },
 	{ 717, "Bad friend file",                                       STATUS_FATAL },
 	{ 731, "Not expected/Invalid argument",                         0 },
-	
+
 	{ 800, "Changing too rapidly",                                  0 },
-	
+
 	{ 910, "Server is busy",                                        STATUS_FATAL },
 	{ 911, "Authentication failed",                                 STATUS_SB_FATAL | STATUS_FATAL },
 	{ 912, "Server is busy",                                        STATUS_FATAL },
@@ -132,24 +138,25 @@ const struct msn_status_code msn_status_code_list[] =
 	{  -1, NULL,                                                    0 }
 };
 
-const struct msn_status_code *msn_status_by_number( int number )
+const struct msn_status_code *msn_status_by_number(int number)
 {
 	static struct msn_status_code *unknown = NULL;
 	int i;
-	
-	for( i = 0; msn_status_code_list[i].number >= 0; i ++ )
-		if( msn_status_code_list[i].number == number )
-			return( msn_status_code_list + i );
-	
-	if( unknown == NULL )
-	{
-		unknown = g_new0( struct msn_status_code, 1 );
-		unknown->text = g_new0( char, 128 );
+
+	for (i = 0; msn_status_code_list[i].number >= 0; i++) {
+		if (msn_status_code_list[i].number == number) {
+			return(msn_status_code_list + i);
+		}
 	}
-	
+
+	if (unknown == NULL) {
+		unknown = g_new0(struct msn_status_code, 1);
+		unknown->text = g_new0(char, 128);
+	}
+
 	unknown->number = number;
 	unknown->flags = 0;
-	g_snprintf( unknown->text, 128, "Unknown error (%d)", number );
-	
-	return( unknown );
+	g_snprintf(unknown->text, 128, "Unknown error (%d)", number);
+
+	return(unknown);
 }
