@@ -28,7 +28,7 @@
 #include "nogaim.h"
 #include "twitter_http.h"
 
-#define TWITTER_API_URL "http://api.twitter.com/1.1"
+#define TWITTER_API_URL "https://api.twitter.com/1.1"
 #define IDENTICA_API_URL "https://identi.ca/api"
 
 /* Status URLs */
@@ -68,8 +68,8 @@
 
 /* Favorites URLs */
 #define TWITTER_FAVORITES_GET_URL "/favorites.json"
-#define TWITTER_FAVORITE_CREATE_URL "/favorites/create/"
-#define TWITTER_FAVORITE_DESTROY_URL "/favorites/destroy/"
+#define TWITTER_FAVORITE_CREATE_URL "/favorites/create.json"
+#define TWITTER_FAVORITE_DESTROY_URL "/favorites/destroy.json"
 
 /* Block URLs */
 #define TWITTER_BLOCKS_CREATE_URL "/blocks/create/"
@@ -78,10 +78,13 @@
 /* Report spam */
 #define TWITTER_REPORT_SPAM_URL "/users/report_spam.json"
 
+/* Stream URLs */
 #define TWITTER_USER_STREAM_URL "https://userstream.twitter.com/1.1/user.json"
+#define TWITTER_FILTER_STREAM_URL "https://stream.twitter.com/1.1/statuses/filter.json"
 
 gboolean twitter_open_stream(struct im_connection *ic);
-void twitter_get_timeline(struct im_connection *ic, gint64 next_cursor);
+gboolean twitter_open_filter_stream(struct im_connection *ic);
+gboolean twitter_get_timeline(struct im_connection *ic, gint64 next_cursor);
 void twitter_get_friends_ids(struct im_connection *ic, gint64 next_cursor);
 void twitter_get_statuses_friends(struct im_connection *ic, gint64 next_cursor);
 
